@@ -75,7 +75,7 @@ class ActivityStore(gtk.ListStore):
         if category_id is None:
             return
 
-        activity_list = runtime.storage.get_activities(category_id)
+        activity_list = runtime.storage.get_category_activities(category_id)
 
         for activity in activity_list:
             self.append([activity['id'],
@@ -108,6 +108,15 @@ class PreferencesEditor:
         self._gui = stuff.load_ui_file("preferences.ui")
         self.window = self.get_widget('preferences_window')
 
+        self.activities_sources = [("", _("None")),
+                                   ("evo", "Evolution"),
+                                   ("gtg", "Getting Things Gnome")]
+        self.todo_combo = gtk.combo_box_new_text()
+        for code, label in self.activities_sources:
+            self.todo_combo.append_text(label)
+        self.todo_combo.connect("changed", self.on_todo_combo_changed)
+        self.get_widget("todo_pick").add(self.todo_combo)
+
 
         # create and fill activity tree
         self.activity_tree = self.get_widget('activity_list')
@@ -233,6 +242,10 @@ class PreferencesEditor:
         self._gui.connect_signals(self)
         self.window.show_all()
 
+
+    def on_todo_combo_changed(self, combo):
+        conf.set("activities_source", self.activities_sources[combo.get_active()][0])
+
     def workspace_name_celldata(self, column, cell, model, iter, user_data=None):
         name = model.get_value(iter, 1).get_name()
         cell.set_property('text', str(name))
@@ -268,8 +281,10 @@ class PreferencesEditor:
         self.get_widget("shutdown_track").set_active(conf.get("stop_on_shutdown"))
         self.get_widget("idle_track").set_active(conf.get("enable_timeout"))
         self.get_widget("notify_interval").set_value(conf.get("notify_interval"))
-        self.get_widget("keybinding").set_text(conf.get("keybinding"))
+
         self.get_widget("notify_on_idle").set_active(conf.get("notify_on_idle"))
+        self.get_widget("notify_on_idle").set_sensitive(conf.get("notify_interval") <=120)
+
         self.get_widget("workspace_tracking_name").set_active("name" in conf.get("workspace_tracking"))
         self.get_widget("workspace_tracking_memory").set_active("memory" in conf.get("workspace_tracking"))
 
@@ -277,13 +292,19 @@ class PreferencesEditor:
         day_start = dt.time(day_start / 60, day_start % 60)
         self.day_start.set_time(day_start)
 
-        self.tags = [tag["name"] for tag in runtime.storage.get_tags()]
+        self.tags = [tag["name"] for tag in runtime.storage.get_tags(only_autocomplete=True)]
         self.get_widget("autocomplete_tags").set_text(", ".join(self.tags))
 
         self.workspace_mapping = conf.get("workspace_mapping")
         self.get_widget("workspace_list").set_sensitive(self.get_widget("workspace_tracking_name").get_active())
 
 
+        current_source = conf.get("activities_source")
+        for i, (code, label) in enumerate(self.activities_sources):
+            if code == current_source:
+                self.todo_combo.set_active(i)
+
+
     def on_autocomplete_tags_view_focus_out_event(self, view, event):
         buf = self.get_widget("autocomplete_tags")
         updated_tags = buf.get_text(buf.get_start_iter(), buf.get_end_iter(), 0) \
@@ -445,11 +466,12 @@ class PreferencesEditor:
         id = model[path][0]
         category_id = model[path][2]
 
-        #look for dupes
-        activities = runtime.storage.get_activities(category_id)
+
+        # avoid two activities in same category with same name
+        activities = runtime.storage.get_category_activities(category_id)
         for activity in activities:
-            if activity['name'].lower() == new_text.lower():
-                if id == -1: # that was a new category
+            if id != activity['id'] and activity['name'].lower() == new_text.lower():
+                if id == -1: # that was a new activity
                     self.activity_store.remove(model.get_iter(path))
                 self.select_activity(activity['id'])
                 return False
@@ -766,12 +788,9 @@ class PreferencesEditor:
         conf.set("notify_interval", value)
         self.get_widget("notify_on_idle").set_sensitive(value <= 120)
 
-    def on_keybinding_changed(self, textbox):
-        conf.set("keybinding", textbox.get_text().decode('utf8', 'replace'))
-
     def on_day_start_changed(self, widget):
         day_start = self.day_start.get_time()
-        if not day_start:
+        if day_start is None:
             return
 
         day_start = day_start.hour * 60 + day_start.minute
